@@ -16,14 +16,12 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-/* gdmchooser discovers hosts running XDMCP on the local network(s),
+/* gdmchooser discovers hosts running XDMCP on the local network (s),
  * presents a list of them and allows the user to choose one. The
  * selected hostname will be printed on stdout. */
 
 #include <config.h>
-#include <libgnome/libgnome.h>
-#include <libgnomeui/libgnomeui.h>
-#include <glade/glade.h>
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <dirent.h>
@@ -48,12 +46,17 @@
 #include <sys/sockio.h>
 #endif
 
-#include <viciousui.h>
+#include <libgnome/libgnome.h>
+#include <libgnomeui/libgnomeui.h>
+#include <glade/glade.h>
 
 #include "gdm.h"
 #include "misc.h"
 #include "gdmwm.h"
 #include "gdmcommon.h"
+#include "gdmconfig.h"
+
+#include "viciousui.h"
 
 static gchar *config_file;
 
@@ -92,7 +95,7 @@ static void gdm_chooser_abort (const gchar *format, ...) G_GNUC_PRINTF (1, 2);
 static void gdm_chooser_warn (const gchar *format, ...) G_GNUC_PRINTF (1, 2);
 
 /* Exported for glade */
-void gdm_chooser_cancel (void);
+void gdm_chooser_cancel (/*void*/);
 void gdm_chooser_add_host (void);
 void gdm_chooser_add_entry_changed (void);
 void gdm_chooser_manage (GtkButton *button, gpointer data);
@@ -147,44 +150,14 @@ static XdmcpBuffer querybuf;
 static GSList *bcaddr;
 static GSList *queryaddr;
 
-static gint  GdmXineramaScreen;
-static gint  GdmIconMaxHeight;
-static gint  GdmIconMaxWidth;
-static gboolean  GdmDebug;
-static gint  GdmScanTime;
-static gchar *GdmHostIconDir;
-static gchar *GdmHostDefaultIcon;
-static gchar *GdmGtkRC;
-static gchar *GdmGtkTheme;
-static gchar *GdmHosts;
-static gchar *GdmHostsOrig;
-static gboolean GdmBroadcast;
-static gboolean GdmAllowAdd;
-static gchar *GdmBackgroundColor;
-static int GdmBackgroundType;
-
-static gboolean GdmMulticast;
-static gchar *GdmMulticastAddr;
-
-/* HACK: for gdmcommon, else it complains */
-/* */  gchar *GdmInfoMsgFile;
-/* */  gchar *GdmInfoMsgFont;
-/* */  gchar *GdmSoundProgram;
-/* */  gboolean GdmSoundOnLoginReady;
-/* */  gchar *GdmSoundOnLoginReadyFile;
-/* */  void
-/* */  gdm_kill_thingies (void)
-/* */  {
-/* */	  ; /* nothing */
-/* */  }
-
-
 enum {
 	GDM_BACKGROUND_NONE = 0,
 	GDM_BACKGROUND_IMAGE = 1,
 	GDM_BACKGROUND_COLOR = 2
 };
 
+static gchar *GdmHosts;
+
 static GladeXML *chooser_app;
 static GtkWidget *chooser, *manage, *rescan, *cancel, *add_entry, *add_button;
 static GtkWidget *status_label;
@@ -241,6 +214,7 @@ gdm_chooser_host_alloc (const char *hostname,
     GdmChooserHost *host;
     GdkPixbuf *img;
     gchar *hostimg;
+    gchar *hostimgdir;
 
     host = g_new0 (GdmChooserHost, 1);
     host->name = g_strdup (hostname);
@@ -259,25 +233,29 @@ gdm_chooser_host_alloc (const char *hostname,
     if ( ! willing)
 	    return host;
 
-    hostimg = g_strconcat (GdmHostIconDir, "/", hostname, NULL);
+    hostimgdir = gdm_config_get_string (GDM_KEY_HOST_IMAGE_DIR); 
+    hostimg    = g_strconcat (hostimgdir, "/", hostname, NULL);
     if (access (hostimg, R_OK) != 0) {
 	    g_free (hostimg);
-	    hostimg = g_strconcat (GdmHostIconDir, "/", hostname, ".png", NULL);
+	    hostimg = g_strconcat (hostimgdir, "/", hostname, ".png", NULL);
     }
 
     if (access (hostimg, R_OK) == 0 &&
 	(img = gdk_pixbuf_new_from_file (hostimg, NULL)) != NULL) {
-	gint w, h;
+	gint w, h, maxw, maxh;
 
 	w = gdk_pixbuf_get_width (img);
 	h = gdk_pixbuf_get_height (img);
 	
-	if (w>h && w>GdmIconMaxWidth) {
-	    h = h * ((gfloat) GdmIconMaxWidth/w);
-	    w = GdmIconMaxWidth;
-	} else if (h>GdmIconMaxHeight) {
-	    w = w * ((gfloat) GdmIconMaxHeight/h);
-	    h = GdmIconMaxHeight;
+	maxw = gdm_config_get_int (GDM_KEY_MAX_ICON_WIDTH);
+	maxh = gdm_config_get_int (GDM_KEY_MAX_ICON_HEIGHT);
+
+	if (w > h && w > maxw) {
+	    h = h * ((gfloat) maxw / w);
+	    w = maxw;
+	} else if (h > maxh) {
+	    w = w * ((gfloat) maxh / h);
+	    h = maxh;
 	}
 
 
@@ -508,7 +486,7 @@ gdm_chooser_decode_packet (GIOChannel   *source,
 	    if (! XdmcpReadARRAY8 (&buf, &stat))
 		    goto done;
 
-	    status = g_strndup (stat.data, MIN (stat.length, 256));
+	    status = g_strndup ((char *) stat.data, MIN (stat.length, 256));
     } else if (header.opcode == UNWILLING) {
 	    /* immaterial, will not be shown */
 	    status = NULL;
@@ -532,7 +510,7 @@ gdm_chooser_decode_packet (GIOChannel   *source,
         if ( ! is_loopback_addr ((gchar *) &clnt6_sa.sin6_addr, AF_INET6)) {
 	    clnt6_sa.sin6_scope_id = 0;
 	
-	    getnameinfo ((struct sockaddr *)&clnt6_sa, sizeof (struct sockaddr_in6), hbuf, sizeof(hbuf), NULL, 0, 0);
+	    getnameinfo ((struct sockaddr *)&clnt6_sa, sizeof (struct sockaddr_in6), hbuf, sizeof (hbuf), NULL, 0, 0);
 
 	    hostname = hbuf;
 
@@ -713,7 +691,7 @@ gdm_chooser_find_bcaddr (void)
 	}
 
 	ifr = ifc.ifc_req;
-	num = ifc.ifc_len / sizeof(struct ifreq);
+	num = ifc.ifc_len / sizeof (struct ifreq);
 	for (i = 0 ; i < num ; i++) {
 		if ( ! ve_string_empty (ifr[i].ifr_name)) {
 			struct ifreq ifreq;
@@ -800,8 +778,11 @@ gdm_chooser_find_mcaddr (void)
 			sin6->sin6_family = AF_INET6;
 			sin6->sin6_port = htons (XDM_UDP_PORT);
 			sin6->sin6_scope_id = ifindex;
-			inet_pton (AF_INET6, GdmMulticastAddr, &sin6->sin6_addr);
-			bcaddr = g_slist_append (bcaddr, sin6);   /* bcaddr is also serving for multicast address for IPv6 */
+			inet_pton (AF_INET6, gdm_config_get_string (GDM_KEY_MULTICAST_ADDR),
+				&sin6->sin6_addr);
+
+			/* bcaddr is also serving for multicast address for IPv6 */
+			bcaddr = g_slist_append (bcaddr, sin6);
 		}
 }
 #endif
@@ -851,7 +832,7 @@ do_ping (gboolean full)
 		    char tmpaddr[30];
 		    struct in6_addr in6;
 
-		    sprintf (tmpaddr, "::ffff:%s", inet_ntoa(((struct sockaddr_in *)(ia))->sin_addr));
+		    sprintf (tmpaddr, "::ffff:%s", inet_ntoa (((struct sockaddr_in *)(ia))->sin_addr));
 		    inet_pton (AF_INET6, tmpaddr, &in6);
 		    memcpy (sock6.sin6_addr.s6_addr, in6.s6_addr, sizeof (struct in6_addr));
 		    XdmcpFlush (sockfd, &bcbuf, (XdmcpNetaddr) &sock6, (int) sizeof (struct sockaddr_in6));
@@ -882,7 +863,7 @@ do_ping (gboolean full)
 		    char tmpaddr[30];
 		    struct in6_addr in6;
 
-		    sprintf (tmpaddr, "::ffff:%s", inet_ntoa(((struct sockaddr_in *)(ia))->sin_addr));
+		    sprintf (tmpaddr, "::ffff:%s", inet_ntoa (((struct sockaddr_in *)(ia))->sin_addr));
 		    inet_pton (AF_INET6, tmpaddr, &in6);
 
 		    if (full || ! gdm_host_known ((char *)&((struct sockaddr_in6 *)ia)->sin6_addr, AF_INET6)) {
@@ -957,7 +938,7 @@ gdm_chooser_xdmcp_discover (void)
 
     if (scan_time_handler > 0)
 	    g_source_remove (scan_time_handler);
-    scan_time_handler = g_timeout_add (GdmScanTime * 1000, 
+    scan_time_handler = g_timeout_add (gdm_config_get_int (GDM_KEY_SCAN_TIME) * 1000, 
 				       chooser_scan_time_update, NULL);
 
     /* Note we already used up one try */
@@ -980,11 +961,11 @@ from_hex (const char *s, char *d, int len)
     {
       if (!ishexdigit(*s))
  return 1;
-      t = HexChar (*s) << 4;
+      t = HexChar(*s) << 4;
       s++;
       if (!ishexdigit(*s))
  return 1;
-      t += HexChar (*s);
+      t += HexChar(*s);
       s++;
       *d++ = t;
       len -= 2;
@@ -1124,7 +1105,7 @@ gdm_chooser_xdmcp_init (char **hosts)
 #endif
     if ( ! have_ipv6) {
 	if ((sockfd = socket (AF_INET, SOCK_DGRAM, 0)) == -1) {
-	    gdm_chooser_abort ("Could not create socket()!");
+	    gdm_chooser_abort ("Could not create socket ()!");
 	}
     }
 
@@ -1156,7 +1137,7 @@ gdm_chooser_xdmcp_init (char **hosts)
 			GINT_TO_POINTER (sockfd), NULL);
     g_io_channel_unref (channel);
 
-    gdm_chooser_xdmcp_discover();
+    gdm_chooser_xdmcp_discover ();
 }
 
 static void
@@ -1372,7 +1353,7 @@ gdm_chooser_add_host (void)
 				char tmpaddr [30];
 
 				sprintf (tmpaddr, "::ffff:%s",
-				  inet_ntoa(((struct sockaddr_in *)result->ai_addr)->sin_addr));
+				  inet_ntoa (((struct sockaddr_in *)result->ai_addr)->sin_addr));
 				inet_pton (AF_INET6, tmpaddr, &qa6->sin6_addr);
 			}
 		}
@@ -1532,7 +1513,7 @@ gdm_chooser_add_entry_changed (void)
 }
 
 void
-gdm_chooser_cancel (void)
+gdm_chooser_cancel (/*void*/)
 {
     if (scan_time_handler > 0) {
 	    g_source_remove (scan_time_handler);
@@ -1557,7 +1538,7 @@ gdm_chooser_manage (GtkButton *button, gpointer data)
     if (curhost)
       gdm_chooser_choose_host (curhost->name);
    
-    closelog();
+    closelog ();
 
     /* exit rather gtk_main_quit, it's just safer this way we don't
        have to worry about random whackiness happening */
@@ -1597,62 +1578,6 @@ gdm_chooser_warn (const gchar *format, ...)
     g_free (s);
 }
 
-
-static void 
-gdm_chooser_parse_config (void)
-{
-    VeConfig *cfg;
-
-    cfg = ve_config_get (config_file);
-
-    GdmXineramaScreen = ve_config_get_int (cfg, GDM_KEY_XINERAMA_SCREEN);
-    GdmGtkRC = ve_config_get_string (cfg, GDM_KEY_GTKRC);
-    GdmGtkTheme = ve_config_get_string (cfg, GDM_KEY_GTK_THEME);
-    GdmScanTime = ve_config_get_int (cfg, GDM_KEY_SCAN_TIME);
-    GdmHostDefaultIcon = ve_config_get_string (cfg, GDM_KEY_DEFAULT_HOST_IMG);
-    GdmHostIconDir = ve_config_get_string (cfg, GDM_KEY_HOST_IMAGE_DIR);
-    GdmIconMaxWidth = ve_config_get_int (cfg, GDM_KEY_ICON_WIDTH);
-    GdmIconMaxHeight = ve_config_get_int (cfg, GDM_KEY_ICON_HEIGHT);
-    GdmDebug = ve_config_get_bool (cfg, GDM_KEY_DEBUG);
-
-    GdmBackgroundColor = ve_config_get_string (cfg, GDM_KEY_BACKGROUND_COLOR);
-    GdmBackgroundType = ve_config_get_int (cfg, GDM_KEY_BACKGROUND_TYPE);
-    GdmMulticast = ve_config_get_bool (cfg, GDM_KEY_MULTICAST);
-    GdmMulticastAddr = ve_config_get_string (cfg, GDM_KEY_MULTICAST_ADDR);
-
-    GdmAllowAdd = ve_config_get_bool (cfg, GDM_KEY_ALLOW_ADD);
-
-    /* note that command line arguments will prevail over these */
-    GdmHosts = ve_config_get_string (cfg, GDM_KEY_HOSTS);
-    GdmHostsOrig = g_strdup (GdmHosts);
-    GdmBroadcast = ve_config_get_bool (cfg, GDM_KEY_BROADCAST);
-    /* if broadcasting, then append BROADCAST to hosts */
-    if (GdmBroadcast) {
-	    if (ve_string_empty (GdmHosts)) {
-		    g_free (GdmHosts);
-		    GdmHosts = "BROADCAST";
-	    } else {
-		    char *tmp = g_strconcat (GdmHosts, ",BROADCAST", NULL);
-		    g_free (GdmHosts);
-		    GdmHosts = tmp;
-	    }
-    }
-
-#ifdef ENABLE_IPV6
-    if (GdmMulticast) {
-	    if (ve_string_empty (GdmHosts)) {
-		    g_free (GdmHosts);
-		    GdmHosts = "MULTICAST";
-	    } else {
-		    GdmHosts = g_strconcat (GdmHosts, ",MULTICAST", NULL);
-	    }
-    }
-#endif
-    if (GdmScanTime < 1) GdmScanTime = 1;
-    if (GdmIconMaxWidth < 0) GdmIconMaxWidth = 128;
-    if (GdmIconMaxHeight < 0) GdmIconMaxHeight = 128;
-}
-
 static void
 host_selected (GtkTreeSelection *selection, gpointer data)
 {
@@ -1710,10 +1635,11 @@ display_chooser_information (void)
 static void 
 gdm_chooser_gui_init (void)
 {
-	int width;
-	int height;
 	GtkTreeSelection *selection;
 	GtkTreeViewColumn *column;
+	gchar *defaulthosticon;
+	int width;
+	int height;
 
 	glade_helper_add_glade_directory (GDM_GLADE_DIR);
 	glade_helper_search_gnome_dirs (FALSE);
@@ -1722,21 +1648,23 @@ gdm_chooser_gui_init (void)
     if (RUNNING_UNDER_GDM) {
 	const char *theme_name;
 
-	if( ! ve_string_empty (GdmGtkRC))
-		gtk_rc_parse (GdmGtkRC);
+	if ( ! ve_string_empty (gdm_config_get_string (GDM_KEY_GTKRC)))
+		gtk_rc_parse (gdm_config_get_string (GDM_KEY_GTKRC));
 
 	theme_name = g_getenv ("GDM_GTK_THEME");
 	if (ve_string_empty (theme_name))
-		theme_name = GdmGtkTheme;
+		theme_name = gdm_config_get_string (GDM_KEY_GTK_THEME);
 
 	if ( ! ve_string_empty (theme_name)) {
 		gdm_set_theme (theme_name);
 	}
     }
 
+    defaulthosticon = gdm_config_get_string (GDM_KEY_DEFAULT_HOST_IMG);
+
     /* Load default host image */
-    if (access (GdmHostDefaultIcon, R_OK) != 0) {
-	gdm_chooser_warn (_("Can't open default host icon: %s"), GdmHostDefaultIcon);
+    if (access (defaulthosticon, R_OK) != 0) {
+	gdm_chooser_warn (_("Can't open default host icon: %s"), defaulthosticon);
 	/* bogus image */
 	defhostimg = gdk_pixbuf_new (GDK_COLORSPACE_RGB,
 				     FALSE /* has_alpha */,
@@ -1744,7 +1672,7 @@ gdm_chooser_gui_init (void)
 				     48 /* width */,
 				     48 /* height */);
     } else {
-	defhostimg = gdk_pixbuf_new_from_file (GdmHostDefaultIcon, NULL);
+	defhostimg = gdk_pixbuf_new_from_file (defaulthosticon, NULL);
     }
 
     /* Main window */
@@ -1810,7 +1738,7 @@ gdm_chooser_gui_init (void)
 					  GTK_SORT_ASCENDING);
 
 
-    if ( ! GdmAllowAdd) {
+    if ( ! gdm_config_get_bool (GDM_KEY_ALLOW_ADD)) {
 	    GtkWidget *w = glade_helper_get (chooser_app, "add_hbox",
 					     GTK_TYPE_HBOX);
 	    gtk_widget_hide (w);
@@ -1847,64 +1775,28 @@ gdm_chooser_gui_init (void)
     }
 }
 
-static gboolean
-string_same (VeConfig *config, const char *cur, const char *key)
-{
-	char *val = ve_config_get_string (config, key);
-	if (strcmp (ve_sure_string (cur), ve_sure_string (val)) == 0) {
-		g_free (val);
-		return TRUE;
-	} else {
-		g_free (val);
-		return FALSE;
-	}
-}
-
-static gboolean
-bool_same (VeConfig *config, gboolean cur, const char *key)
-{
-	gboolean val = ve_config_get_bool (config, key);
-	if (ve_bool_equal (cur, val)) {
-		return TRUE;
-	} else {
-		return FALSE;
-	}
-}
-
-static gboolean
-int_same (VeConfig *config, int cur, const char *key)
-{
-	int val = ve_config_get_int (config, key);
-	if (cur == val) {
-		return TRUE;
-	} else {
-		return FALSE;
-	}
-}
-
-
 static gboolean
 gdm_reread_config (int sig, gpointer data)
 {
-	VeConfig *config;
 	/* reparse config stuff here.  At least ones we care about */
 
-	config = ve_config_get (config_file);
-
 	/* FIXME: The following is evil, we should update on the fly rather
 	 * then just restarting */
 	/* Also we may not need to check ALL those keys but just a few */
-	if ( ! string_same (config, GdmHostsOrig, GDM_KEY_HOSTS) ||
-	     ! string_same (config, GdmGtkRC, GDM_KEY_GTKRC) ||
-	     ! string_same (config, GdmGtkTheme, GDM_KEY_GTK_THEME) ||
-	     ! string_same (config, GdmHostDefaultIcon, GDM_KEY_DEFAULT_HOST_IMG) ||
-	     ! string_same (config, GdmHostIconDir, GDM_KEY_HOST_IMAGE_DIR) ||
-	     ! int_same (config,
-			 GdmXineramaScreen, GDM_KEY_XINERAMA_SCREEN) ||
-	     ! int_same (config, GdmIconMaxWidth, GDM_KEY_ICON_WIDTH) ||
-	     ! int_same (config, GdmIconMaxHeight, GDM_KEY_ICON_HEIGHT) ||
-	     ! int_same (config, GdmScanTime, GDM_KEY_SCAN_TIME) ||
-	     ! bool_same (config, GdmDebug, GDM_KEY_DEBUG)) {
+	if (gdm_config_reload_string (GDM_KEY_HOSTS) ||
+	    gdm_config_reload_string (GDM_KEY_GTKRC) ||
+            gdm_config_reload_string (GDM_KEY_GTK_THEME) ||
+	    gdm_config_reload_string (GDM_KEY_DEFAULT_HOST_IMG) ||
+            gdm_config_reload_string (GDM_KEY_HOST_IMAGE_DIR) ||
+            gdm_config_reload_string (GDM_KEY_MULTICAST_ADDR) ||
+            gdm_config_reload_int    (GDM_KEY_XINERAMA_SCREEN) ||
+            gdm_config_reload_int    (GDM_KEY_MAX_ICON_WIDTH) ||
+            gdm_config_reload_int    (GDM_KEY_MAX_ICON_HEIGHT) ||
+	    gdm_config_reload_int    (GDM_KEY_SCAN_TIME) ||
+            gdm_config_reload_bool   (GDM_KEY_ALLOW_ADD) ||
+            gdm_config_reload_bool   (GDM_KEY_MULTICAST) ||
+            gdm_config_reload_bool   (GDM_KEY_DEBUG)) {
+
 		if (RUNNING_UNDER_GDM) {
 			/* Set busy cursor */
 			gdm_common_setup_cursor (GDK_WATCH);
@@ -1918,12 +1810,11 @@ gdm_reread_config (int sig, gpointer data)
 	}
 
 	/* we only use the color and do it for all types except NONE */
-	if ( ! string_same (config, GdmBackgroundColor, GDM_KEY_BACKGROUND_COLOR) ||
-	     ! int_same (config, GdmBackgroundType, GDM_KEY_BACKGROUND_TYPE)) {
+	if (gdm_config_reload_string (GDM_KEY_BACKGROUND_COLOR) ||
+	    gdm_config_reload_int    (GDM_KEY_BACKGROUND_TYPE)) {
 
-		if (GdmBackgroundType != GDM_BACKGROUND_NONE) {
-			setup_background_color (GdmBackgroundColor);
-		}
+		if (gdm_config_get_int (GDM_KEY_BACKGROUND_TYPE) != GDM_BACKGROUND_NONE)
+			setup_background_color (gdm_config_get_string (GDM_KEY_BACKGROUND_COLOR));
 	}
 
 	return TRUE;
@@ -1941,10 +1832,10 @@ gdm_chooser_signals_init (void)
 
     hup.sa_handler = ve_signal_notify;
     hup.sa_flags = 0;
-    sigemptyset(&hup.sa_mask);
+    sigemptyset (&hup.sa_mask);
     sigaddset (&hup.sa_mask, SIGCHLD);
 
-    term.sa_handler = (void *) gdm_chooser_cancel;
+    term.sa_handler = gdm_chooser_cancel;
     term.sa_flags = 0;
     sigemptyset (&term.sa_mask);
 
@@ -2015,6 +1906,7 @@ main (int argc, char *argv[])
     int nextopt;
     const char *gdm_version;
     int i;
+    guint sid;
 
     stored_argv = g_new0 (char *, argc + 1);
     for (i = 0; i < argc; i++)
@@ -2025,7 +1917,7 @@ main (int argc, char *argv[])
     if (g_getenv ("RUNNING_UNDER_GDM") != NULL)
 	    RUNNING_UNDER_GDM = TRUE;
 
-    openlog ("gdmchooser", LOG_PID, LOG_DAEMON);
+    gdm_openlog ("gdmchooser", LOG_PID, LOG_DAEMON);
 
     bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
     bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
@@ -2046,7 +1938,7 @@ main (int argc, char *argv[])
 	    exit (1);
     }
 
-    glade_init();
+    glade_init ();
 
     config_file = gdm_common_get_config_file ();
     if (config_file == NULL) {
@@ -2054,10 +1946,29 @@ main (int argc, char *argv[])
 	    exit (EXIT_FAILURE);
     }
         
-    gdm_chooser_parse_config();
+    /* if broadcasting, then append BROADCAST to hosts */
+    if (gdm_config_get_bool (GDM_KEY_BROADCAST)) {
+	    gchar *hosts = gdm_config_get_string (GDM_KEY_HOSTS);
+	    if (ve_string_empty (hosts)) {
+		    GdmHosts = "BROADCAST";
+	    } else {
+		    GdmHosts = g_strconcat (hosts, ",BROADCAST", NULL);
+	    }
+    }
+
+#ifdef ENABLE_IPV6
+    if (gdm_config_get_bool (GDM_KEY_MULTICAST)) {
+	    gchar *hosts = gdm_config_get_string (GDM_KEY_HOSTS);
+	    if (ve_string_empty (hosts)) {
+		    GdmHosts = "MULTICAST";
+	    } else {
+		    GdmHosts = g_strconcat (GdmHosts, ",MULTICAST", NULL);
+	    }
+    }
+#endif
 
     if (RUNNING_UNDER_GDM)
-	    gdm_wm_screen_init (GdmXineramaScreen);
+	    gdm_wm_screen_init (gdm_config_get_int (GDM_KEY_XINERAMA_SCREEN));
 
     gdm_version = g_getenv ("GDM_VERSION");
 
@@ -2065,8 +1976,8 @@ main (int argc, char *argv[])
     /* the background unfilled.   The cursor should be a watch already */
     /* but just in case */
     if (RUNNING_UNDER_GDM) {
-	if (GdmBackgroundType != GDM_BACKGROUND_NONE)
-		setup_background_color (GdmBackgroundColor);
+	if (gdm_config_get_int (GDM_KEY_BACKGROUND_TYPE) != GDM_BACKGROUND_NONE)
+		setup_background_color (gdm_config_get_string (GDM_KEY_BACKGROUND_COLOR));
 
 	gdm_common_setup_cursor (GDK_WATCH);
     }
@@ -2107,8 +2018,8 @@ main (int argc, char *argv[])
     
     gtk_window_set_default_icon_from_file (DATADIR"/pixmaps/gdm-xnest.png", NULL);
 
-    gdm_chooser_gui_init();
-    gdm_chooser_signals_init();
+    gdm_chooser_gui_init ();
+    gdm_chooser_signals_init ();
 
     hosts = (char **)poptGetArgs (ctx);
     /* when no hosts on the command line, take them from the config */
@@ -2123,7 +2034,7 @@ main (int argc, char *argv[])
     gdm_chooser_xdmcp_init (hosts);
     poptFreeContext (ctx);
 
-    guint sid = g_signal_lookup ("event",
+    sid = g_signal_lookup ("event",
 				 GTK_TYPE_WIDGET);
     g_signal_add_emission_hook (sid,
 				0 /* detail */,
@@ -2148,7 +2059,7 @@ main (int argc, char *argv[])
 	    gdm_wm_focus_window (GDK_WINDOW_XWINDOW (chooser->window));
     }
 
-    if (GdmAllowAdd)
+    if (gdm_config_get_bool (GDM_KEY_ALLOW_ADD))
 	    gtk_widget_grab_focus (add_entry);
 
     gdm_chooser_add_entry_changed ();
@@ -2158,10 +2069,9 @@ main (int argc, char *argv[])
 	    gdm_common_setup_cursor (GDK_LEFT_PTR);
     }
 
-    gtk_main();
+    gtk_main ();
 
     exit (EXIT_SUCCESS);
 }
 
-
 /* EOF */
