@@ -35,23 +35,21 @@
 #include <sys/un.h>
 #include <errno.h>
 
-#include <viciousui.h>
-
 #include "gdm.h"
 #include "gdmcomm.h"
 #include "gdmcommon.h"
+#include "gdmconfig.h"
 
 static char *myname = NULL;  /* name of this program */
 
-
 static void
-usage()
+usage ()
 {
-    fprintf(stderr, "Usage: %s [-b][-v] and one of the following:\n", myname);
-    fprintf(stderr, "\t-a display\n");
-    fprintf(stderr, "\t-r display\n");
-    fprintf(stderr, "\t-d display\n");
-    fprintf(stderr, "\t-l [server_name]\n");
+    fprintf (stderr, "Usage: %s [-b][-v] and one of the following:\n", myname);
+    fprintf (stderr, "\t-a display\n");
+    fprintf (stderr, "\t-r display\n");
+    fprintf (stderr, "\t-d display\n");
+    fprintf (stderr, "\t-l [server_name]\n");
 }
 
 
@@ -68,14 +66,13 @@ main (int argc, char *argv[])
     int background = 0;
     gboolean error = TRUE;
     char *cookie = NULL;
-    gchar *config_file;
 
-    myname = basename(argv[0]);
+    myname = basename (argv[0]);
     argv[0] = myname;
 
     version = "2.8.0.0";
 
-    while ((optc = getopt(argc, argv, "a:d:r:blv")) != EOF) {
+    while ((optc = getopt (argc, argv, "a:d:r:blv")) != EOF) {
         switch (optc) {
         case 'a':
             if (command == NULL)
@@ -118,8 +115,8 @@ main (int argc, char *argv[])
     }
 
     if (error) {
-        usage();
-        exit(1);
+        usage ();
+        exit (1);
     }
 
     /* process remaining option arguments for -l */
@@ -130,43 +127,35 @@ main (int argc, char *argv[])
     /* handle background option by forking and exiting the parent */
 
     if (background) {
-        if ((background = fork()) != 0)  {
+        if ((background = fork ()) != 0)  {
             if (background < 0)
-                exit(1);
+                exit (1);
             else
-                exit(0);
+                exit (0);
         }
     }
 
     gdmcomm_set_debug (verbose);
 
-    if (params && strlen(params))
+    if (params && strlen (params))
         cstr = g_strdup_printf ("%s %s", command, params);
     else
-        cstr = g_strdup(command);
+        cstr = g_strdup (command);
 
     /* All other commands besides LIST need root cookie */
-    if (strcmp(command, GDM_SUP_ATTACHED_SERVERS) != 0) {
+    if (strcmp (command, GDM_SUP_ATTACHED_SERVERS) != 0) {
         char  *filename;
         gchar *GdmServAuthDir = NULL;
         FILE  *fp;
         char  buf[BUFSIZ];
 
-	config_file = gdm_common_get_config_file ();
-	if (config_file == NULL) {
-		g_print (_("Could not access GDM configuration file.\n"));
-		exit (1);
-	}
-
-        GdmServAuthDir = ve_config_get_string (ve_config_get (config_file),
-                                               GDM_KEY_SERV_AUTHDIR);
-	g_free (config_file);
+        GdmServAuthDir = gdm_config_get_string (GDM_KEY_SERV_AUTHDIR);
         filename = g_build_filename (GdmServAuthDir, ".cookie", NULL);
 
         VE_IGNORE_EINTR (fp = fopen (filename, "r"));
         if (fp != NULL) {
-            fgets(buf, sizeof(buf), fp);
-            cookie = g_strdup(buf);
+            fgets (buf, sizeof (buf), fp);
+            cookie = g_strdup (buf);
             VE_IGNORE_EINTR (fclose (fp));
         }
 	g_free (filename);
@@ -174,21 +163,21 @@ main (int argc, char *argv[])
 
     ret = gdmcomm_call_gdm (cstr, cookie, version, 5);
 
-    g_free(cstr);
+    g_free (cstr);
     if (cookie)
-        g_free(cookie);
+        g_free (cookie);
 
     if (verbose && ret != NULL)
-        fprintf(stderr,"%s\n", ret);
+        fprintf (stderr,"%s\n", ret);
 
     if (ret != NULL &&
         strncmp (ret, "OK", 2) == 0) {
 
-        if (strcmp(command, GDM_SUP_ATTACHED_SERVERS) == 0) {
+        if (strcmp (command, GDM_SUP_ATTACHED_SERVERS) == 0) {
             ret += 2;
-            if(strlen(ret)) {
+            if (strlen (ret)) {
                 ret++;   /* skip over space char */
-                printf("%s\n", ret);
+                printf ("%s\n", ret);
             }
         }
 
